==> python-novaclient-2.11.0.tar.gz: python-novaclient-2.11.0/tests/v1_1/test_availability_zone.py <==
# Copyright 2011 OpenStack LLC.
# Copyright 2013 IBM Corp.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from novaclient.v1_1 import availability_zones
from novaclient.v1_1 import shell
from tests.v1_1 import fakes
from tests import utils


cs = fakes.FakeClient()


class AvailabilityZoneTest(utils.TestCase):

    def _assertZone(self, zone, name, status):
        self.assertEqual(zone.zoneName, name)
        self.assertEqual(zone.zoneState, status)

    def test_list_availability_zone(self):
        zones = cs.availability_zones.list(detailed=False)
        cs.assert_called('GET', '/os-availability-zone')

        for zone in zones:
            self.assertTrue(isinstance(zone,
                                       availability_zones.AvailabilityZone))

        self.assertEqual(2, len(zones))

        l0 = [u'zone-1', u'available']
        l1 = [u'zone-2', u'not available']

        z0 = shell._treeizeAvailabilityZone(zones[0])
        z1 = shell._treeizeAvailabilityZone(zones[1])

        self.assertEqual((len(z0), len(z1)), (1, 1))

        self._assertZone(z0[0], l0[0], l0[1])
        self._assertZone(z1[0], l1[0], l1[1])

    def test_detail_availability_zone(self):
        zones = cs.availability_zones.list(detailed=True)
        cs.assert_called('GET', '/os-availability-zone/detail')

        for zone in zones:
            self.assertTrue(isinstance(zone,
                                       availability_zones.AvailabilityZone))

        self.assertEqual(3, len(zones))

        l0 = [u'zone-1', u'available']
        l1 = [u'|- fake_host-1', u'']
        l2 = [u'| |- nova-compute', u'enabled :-) 2012-12-26T14:45:25.000000']
        l3 = [u'internal', u'available']
        l4 = [u'|- fake_host-1', u'']
        l5 = [u'| |- nova-sched', u'enabled :-) 2012-12-26T14:45:25.000000']
        l6 = [u'|- fake_host-2', u'']
        l7 = [u'| |- nova-network', u'enabled XXX 2012-12-26T14:45:24.000000']
        l8 = [u'zone-2', u'not available']

        z0 = shell._treeizeAvailabilityZone(zones[0])
        z1 = shell._treeizeAvailabilityZone(zones[1])
        z2 = shell._treeizeAvailabilityZone(zones[2])

        self.assertEqual((len(z0), len(z1), len(z2)), (3, 5, 1))

        self._assertZone(z0[0], l0[0], l0[1])
        self._assertZone(z0[1], l1[0], l1[1])
        self._assertZone(z0[2], l2[0], l2[1])
        self._assertZone(z1[0], l3[0], l3[1])
        self._assertZone(z1[1], l4[0], l4[1])
        self._assertZone(z1[2], l5[0], l5[1])
        self._assertZone(z1[3], l6[0], l6[1])
        self._assertZone(z1[4], l7[0], l7[1])
        self._assertZone(z2[0], l8[0], l8[1])

==> python-novaclient_2.13.0.orig.tar.gz: python-novaclient-2.13.0/tests/v1_1/test_availability_zone.py <==
# Copyright 2011 OpenStack Foundation
# Copyright 2013 IBM Corp.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from novaclient.v1_1 import availability_zones
from novaclient.v1_1 import shell
from tests.v1_1 import fakes
from tests import utils


cs = fakes.FakeClient()


class AvailabilityZoneTest(utils.TestCase):

    def _assertZone(self, zone, name, status):
        self.assertEqual(zone.zoneName, name)
        self.assertEqual(zone.zoneState, status)

    def test_list_availability_zone(self):
        zones = cs.availability_zones.list(detailed=False)
        cs.assert_called('GET', '/os-availability-zone')

        for zone in zones:
            self.assertTrue(isinstance(zone,
                                       availability_zones.AvailabilityZone))

        self.assertEqual(2, len(zones))

        l0 = [u'zone-1', u'available']
        l1 = [u'zone-2', u'not available']

        z0 = shell._treeizeAvailabilityZone(zones[0])
        z1 = shell._treeizeAvailabilityZone(zones[1])

        self.assertEqual((len(z0), len(z1)), (1, 1))

        self._assertZone(z0[0], l0[0], l0[1])
        self._assertZone(z1[0], l1[0], l1[1])

    def test_detail_availability_zone(self):
        zones = cs.availability_zones.list(detailed=True)
        cs.assert_called('GET', '/os-availability-zone/detail')

        for zone in zones:
            self.assertTrue(isinstance(zone,
                                       availability_zones.AvailabilityZone))

        self.assertEqual(3, len(zones))

        l0 = [u'zone-1', u'available']
        l1 = [u'|- fake_host-1', u'']
        l2 = [u'| |- nova-compute', u'enabled :-) 2012-12-26 14:45:25']
        l3 = [u'internal', u'available']
        l4 = [u'|- fake_host-1', u'']
        l5 = [u'| |- nova-sched', u'enabled :-) 2012-12-26 14:45:25']
        l6 = [u'|- fake_host-2', u'']
        l7 = [u'| |- nova-network', u'enabled XXX 2012-12-26 14:45:24']
        l8 = [u'zone-2', u'not available']

        z0 = shell._treeizeAvailabilityZone(zones[0])
        z1 = shell._treeizeAvailabilityZone(zones[1])
        z2 = shell._treeizeAvailabilityZone(zones[2])

        self.assertEqual((len(z0), len(z1), len(z2)), (3, 5, 1))

        self._assertZone(z0[0], l0[0], l0[1])
        self._assertZone(z0[1], l1[0], l1[1])
        self._assertZone(z0[2], l2[0], l2[1])
        self._assertZone(z1[0], l3[0], l3[1])
        self._assertZone(z1[1], l4[0], l4[1])
        self._assertZone(z1[2], l5[0], l5[1])
        self._assertZone(z1[3], l6[0], l6[1])
        self._assertZone(z1[4], l7[0], l7[1])
        self._assertZone(z2[0], l8[0], l8[1])
